# Exceptions

[Ucndata Index](./README.md#ucndata-index) / Exceptions

> Auto-generated documentation for [exceptions](../ucndata/exceptions.py) module.

- [Exceptions](#exceptions)
  - [BeamError](#beamerror)
  - [CycleError](#cycleerror)
  - [CycleWarning](#cyclewarning)
  - [DataError](#dataerror)
  - [DetectorError](#detectorerror)
  - [MergeError](#mergeerror)
  - [MergeWarning](#mergewarning)
  - [MissingDataError](#missingdataerror)
  - [MissingDataWarning](#missingdatawarning)
  - [NotImplementedError](#notimplementederror)
  - [ValveError](#valveerror)

## BeamError

[Show source in exceptions.py:13](../ucndata/exceptions.py#L13)

#### Signature

```python
class BeamError(DataError): ...
```

#### See also

- [DataError](#dataerror)



## CycleError

[Show source in exceptions.py:14](../ucndata/exceptions.py#L14)

#### Signature

```python
class CycleError(DataError): ...
```

#### See also

- [DataError](#dataerror)



## CycleWarning

[Show source in exceptions.py:19](../ucndata/exceptions.py#L19)

#### Signature

```python
class CycleWarning(Warning): ...
```



## DataError

[Show source in exceptions.py:11](../ucndata/exceptions.py#L11)

#### Signature

```python
class DataError(Exception): ...
```



## DetectorError

[Show source in exceptions.py:15](../ucndata/exceptions.py#L15)

#### Signature

```python
class DetectorError(DataError): ...
```

#### See also

- [DataError](#dataerror)



## MergeError

[Show source in exceptions.py:8](../ucndata/exceptions.py#L8)

#### Signature

```python
class MergeError(Exception): ...
```



## MergeWarning

[Show source in exceptions.py:21](../ucndata/exceptions.py#L21)

#### Signature

```python
class MergeWarning(Warning): ...
```



## MissingDataError

[Show source in exceptions.py:6](../ucndata/exceptions.py#L6)

#### Signature

```python
class MissingDataError(Exception): ...
```



## MissingDataWarning

[Show source in exceptions.py:20](../ucndata/exceptions.py#L20)

#### Signature

```python
class MissingDataWarning(Warning): ...
```



## NotImplementedError

[Show source in exceptions.py:7](../ucndata/exceptions.py#L7)

#### Signature

```python
class NotImplementedError(Exception): ...
```



## ValveError

[Show source in exceptions.py:16](../ucndata/exceptions.py#L16)

#### Signature

```python
class ValveError(DataError): ...
```

#### See also

- [DataError](#dataerror)